==> estateplat-common-1.2.1-20170516.083041-19-sources.jar: cn/gtmap/estateplat/model/server/core/BdcDxfsjl.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
 * @version 1.0, 2017/5/3
 * @description 短信发送记录
 */
@Table(name = "BDC_DXFSJL")
public class BdcDxfsjl {

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 主键
     */
    @Id
    private String id;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 项目主键
     */
    private String proid;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 实例主键
     */
    private String wiid;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 申请类型
     */
    private String sqlx;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 联系电话
     */
    private String lxdh;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 短信内容
     */
    private String dxnr;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 发送时间
     */
    private Date fssj;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 发送状态
     */
    private String fszt;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 短信ID 标识唯一短信
     */
    private String dxid;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getWiid() {
        return wiid;
    }

    public void setWiid(String wiid) {
        this.wiid = wiid;
    }

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public String getLxdh() {
        return lxdh;
    }

    public void setLxdh(String lxdh) {
        this.lxdh = lxdh;
    }

    public String getDxnr() {
        return dxnr;
    }

    public void setDxnr(String dxnr) {
        this.dxnr = dxnr;
    }

    public Date getFssj() {
        return fssj;
    }

    public void setFssj(Date fssj) {
        this.fssj = fssj;
    }

    public String getFszt() {
        return fszt;
    }

    public void setFszt(String fszt) {
        this.fszt = fszt;
    }

    public String getDxid() {
        return dxid;
    }

    public void setDxid(String dxid) {
        this.dxid = dxid;
    }
}

==> estateplat-common-1.2.3-20180309.074542-40-sources.jar: cn/gtmap/estateplat/model/server/core/BdcDxfsjl.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
 * @version 1.0, 2017/5/3
 * @description 短信发送记录
 */
@Table(name = "BDC_DXFSJL")
public class BdcDxfsjl {

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 主键
     */
    @Id
    private String id;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 项目主键
     */
    private String proid;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 实例主键
     */
    private String wiid;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 申请类型
     */
    private String sqlx;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 接收人名称
     */
    private String jsrmc;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 联系电话
     */
    private String lxdh;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 短信内容
     */
    private String dxnr;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 发送时间
     */
    private Date fssj;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 发送状态
     */
    private String fszt;

    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 短信ID 标识唯一短信
     */
    private String dxid;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getWiid() {
        return wiid;
    }

    public void setWiid(String wiid) {
        this.wiid = wiid;
    }

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public String getJsrmc() {
        return jsrmc;
    }

    public void setJsrmc(String jsrmc) {
        this.jsrmc = jsrmc;
    }

    public String getLxdh() {
        return lxdh;
    }

    public void setLxdh(String lxdh) {
        this.lxdh = lxdh;
    }

    public String getDxnr() {
        return dxnr;
    }

    public void setDxnr(String dxnr) {
        this.dxnr = dxnr;
    }

    public Date getFssj() {
        return fssj;
    }

    public void setFssj(Date fssj) {
        this.fssj = fssj;
    }

    public String getFszt() {
        return fszt;
    }

    public void setFszt(String fszt) {
        this.fszt = fszt;
    }

    public String getDxid() {
        return dxid;
    }

    public void setDxid(String dxid) {
        this.dxid = dxid;
    }
}
